@@ -338,7 +338,7 @@ SEXP call_fit_collective_explicit_als
     SEXP k_main_k_user_k_item,
     SEXP w_main_w_user_w_item_w_implicit,
     SEXP niter, SEXP nthreads, SEXP verbose, SEXP handle_interrupt,
-    SEXP use_cg, SEXP max_cg_steps, SEXP finalize_chol,
+    SEXP use_cg, SEXP max_cg_steps, SEXP precondition_cg, SEXP finalize_chol,
     SEXP nonneg, SEXP max_cd_steps, SEXP nonneg_CD,
     SEXP precompute,
     SEXP add_implicit_features,
@@ -424,7 +424,8 @@ SEXP call_fit_collective_explicit_als
         w_main, w_user, w_item, w_implicit,
         Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(handle_interrupt),
-        (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
+        (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps),
+        (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
         nonneg_C, nonneg_D,
         (bool) Rf_asLogical(precompute),
@@ -466,7 +467,7 @@ SEXP call_fit_collective_implicit_als
     SEXP k_main, SEXP k_user, SEXP k_item,
     SEXP w_main, SEXP w_user, SEXP w_item,
     SEXP niter, SEXP nthreads, SEXP verbose, SEXP handle_interrupt,
-    SEXP use_cg, SEXP max_cg_steps, SEXP finalize_chol,
+    SEXP use_cg, SEXP max_cg_steps, SEXP precondition_cg, SEXP finalize_chol,
     SEXP nonneg, SEXP max_cd_steps, SEXP nonneg_C, SEXP nonneg_D,
     SEXP alpha, SEXP adjust_weight, SEXP apply_log_transf,
     SEXP precompute,
@@ -511,9 +512,11 @@ SEXP call_fit_collective_implicit_als
         REAL(w_main_multiplier),
         Rf_asReal(alpha), (bool) Rf_asLogical(adjust_weight),
         (bool) Rf_asLogical(apply_log_transf),
-        Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose),
+        Rf_asInteger(niter), Rf_asInteger(nthreads),
+        (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(handle_interrupt),
-        (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
+        (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps),
+        (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
         (bool) Rf_asLogical(nonneg_C), (bool) Rf_asLogical(nonneg_D),
         (bool) Rf_asLogical(precompute),
@@ -779,7 +782,7 @@ SEXP call_fit_offsets_explicit_als
     SEXP NA_as_zero_X,
     SEXP niter,
     SEXP nthreads, SEXP use_cg,
-    SEXP max_cg_steps, SEXP finalize_chol,
+    SEXP max_cg_steps, SEXP precondition_cg, SEXP finalize_chol,
     SEXP verbose, SEXP handle_interrupt,
     SEXP precompute,
     SEXP Am, SEXP Bm,
@@ -817,8 +820,10 @@ SEXP call_fit_offsets_explicit_als
         get_ptr(II), Rf_asInteger(q),
         (bool) Rf_asLogical(NA_as_zero_X),
         Rf_asInteger(niter),
-        Rf_asInteger(nthreads), (bool) Rf_asLogical(use_cg),
-        Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
+        Rf_asInteger(nthreads),
+        (bool) Rf_asLogical(use_cg),
+        Rf_asInteger(max_cg_steps),
+        (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
         (bool) Rf_asLogical(precompute),
         get_ptr(Am), get_ptr(Bm),
@@ -850,7 +855,7 @@ SEXP call_fit_offsets_implicit_als
     SEXP alpha, SEXP apply_log_transf,
     SEXP niter,
     SEXP nthreads, SEXP use_cg,
-    SEXP max_cg_steps, SEXP finalize_chol,
+    SEXP max_cg_steps, SEXP precondition_cg, SEXP finalize_chol,
     SEXP verbose, SEXP handle_interrupt,
     SEXP precompute,
     SEXP Am, SEXP Bm,
@@ -875,8 +880,10 @@ SEXP call_fit_offsets_implicit_als
         get_ptr(II), Rf_asInteger(q),
         Rf_asReal(alpha), (bool) Rf_asLogical(apply_log_transf),
         Rf_asInteger(niter),
-        Rf_asInteger(nthreads), (bool) Rf_asLogical(use_cg),
-        Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
+        Rf_asInteger(nthreads),
+        (bool) Rf_asLogical(use_cg),
+        Rf_asInteger(max_cg_steps),
+        (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
         (bool) Rf_asLogical(precompute),
         get_ptr(Am), get_ptr(Bm),
@@ -2555,13 +2562,13 @@ static const R_CallMethodDef callMethods [] = {
     {"R_has_openmp", (DL_FUNC) &R_has_openmp, 0},
     /* ---------------------------------------------------- */
     {"call_fit_collective_explicit_lbfgs", (DL_FUNC) &call_fit_collective_explicit_lbfgs, 64},
-    {"call_fit_collective_explicit_als", (DL_FUNC) &call_fit_collective_explicit_als, 64},
-    {"call_fit_collective_implicit_als", (DL_FUNC) &call_fit_collective_implicit_als, 55},
+    {"call_fit_collective_explicit_als", (DL_FUNC) &call_fit_collective_explicit_als, 65},
+    {"call_fit_collective_implicit_als", (DL_FUNC) &call_fit_collective_implicit_als, 56},
     {"call_fit_most_popular", (DL_FUNC) &call_fit_most_popular, 23},
     {"call_fit_content_based_lbfgs", (DL_FUNC) &call_fit_content_based_lbfgs, 43},
     {"call_fit_offsets_explicit_lbfgs", (DL_FUNC) &call_fit_offsets_explicit_lbfgs, 53},
-    {"call_fit_offsets_explicit_als", (DL_FUNC) &call_fit_offsets_explicit_als, 42},
-    {"call_fit_offsets_implicit_als", (DL_FUNC) &call_fit_offsets_implicit_als, 32},
+    {"call_fit_offsets_explicit_als", (DL_FUNC) &call_fit_offsets_explicit_als, 43},
+    {"call_fit_offsets_implicit_als", (DL_FUNC) &call_fit_offsets_implicit_als, 33},
     /* ---------------------------------------------------- */
     {"call_precompute_collective_explicit", (DL_FUNC) &call_precompute_collective_explicit, 36},
     {"call_precompute_collective_implicit", (DL_FUNC) &call_precompute_collective_implicit, 20},
